@@ -14,7 +14,7 @@ with open(path, 'rb') as content_file:
     file_content = content_file.read()
 
 list_title = "Documents"
-target_folder = ctx.web.lists.get_by_title(list_title).rootFolder
+target_folder = ctx.web.lists.get_by_title(list_title).root_folder
 name = os.path.basename(path)
 target_file = target_folder.upload_file(name, file_content)
 ctx.execute_query()
