@@ -10,13 +10,16 @@ from office365.sharepoint.fields.field_collection import FieldCollection
 from office365.sharepoint.fields.related_field_collection import RelatedFieldCollection
 from office365.sharepoint.files.checkedOutFileCollection import CheckedOutFileCollection
 from office365.sharepoint.folders.folder import Folder
-from office365.sharepoint.forms.formCollection import FormCollection
-from office365.sharepoint.listitems.caml.camlQuery import CamlQuery
+from office365.sharepoint.forms.form_collection import FormCollection
+from office365.sharepoint.listitems.caml.caml_query import CamlQuery
+from office365.sharepoint.listitems.creation_information_using_path import ListItemCreationInformationUsingPath
 from office365.sharepoint.listitems.listitem import ListItem
 from office365.sharepoint.listitems.listItem_collection import ListItemCollection
 from office365.sharepoint.permissions.securable_object import SecurableObject
+from office365.sharepoint.usercustomactions.user_custom_action_collection import UserCustomActionCollection
 from office365.sharepoint.views.view import View
 from office365.sharepoint.views.view_collection import ViewCollection
+from office365.sharepoint.webhooks.subscription_collection import SubscriptionCollection
 
 
 class List(SecurableObject):
@@ -25,6 +28,26 @@ class List(SecurableObject):
     def __init__(self, context, resource_path=None):
         super(List, self).__init__(context, resource_path)
 
+    def get_lookup_field_choices(self, targetFieldName, pagingInfo=None):
+        result = ClientResult(str)
+        params = {
+            "targetFieldName": targetFieldName,
+            "pagingInfo": pagingInfo
+        }
+        qry = ServiceOperationQuery(self, "GetLookupFieldChoices", params, None, None, result)
+        self.context.add_query(qry)
+        return result
+
+    def get_list_item_changes_since_token(self, query):
+        """
+
+        :type query: office365.sharepoint.changes.change_log_item_query.ChangeLogItemQuery
+        """
+        result = ClientResult(str)
+        qry = ServiceOperationQuery(self, "getListItemChangesSinceToken", None, query, "query", result)
+        self.context.add_query(qry)
+        return result
+
     def save_as_template(self, fileName, name, description, saveData):
         """
         Saves the list as a template in the list template gallery and includes the option of saving with or
@@ -96,7 +119,7 @@ class List(SecurableObject):
             self.context.add_query(qry)
         else:
             def _resolve_folder_url():
-                list_item_creation_information.FolderUrl = self.context.base_url + self.rootFolder.serverRelativeUrl
+                list_item_creation_information.FolderUrl = self.context.base_url + self.root_folder.serverRelativeUrl
                 add_item_qry = ServiceOperationQuery(
                     self,
                     "addItem",
@@ -107,9 +130,25 @@ class List(SecurableObject):
                 )
                 self.context.add_query(add_item_qry)
 
-            self.rootFolder.ensure_property("ServerRelativeUrl", _resolve_folder_url)
+            self.root_folder.ensure_property("ServerRelativeUrl", _resolve_folder_url)
         return item
 
+    def add_item_using_path(self, leaf_name, object_type, folder_url):
+        """
+        :type leaf_name: str
+        :type object_type: int
+        :type folder_url: str
+        """
+        from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
+        parameters = ListItemCreationInformationUsingPath(leaf_name, object_type, folder_path=SPResPath(folder_url))
+        item = ListItem(self.context)
+        qry = ServiceOperationQuery(self, "AddItemUsingPath", None, parameters, "parameters", item)
+        self.context.add_query(qry)
+        return item
+
+    def add_validate_update_item(self):
+        pass
+
     def get_item_by_id(self, item_id):
         """Returns the list item with the specified list item identifier.
 
@@ -153,12 +192,26 @@ class List(SecurableObject):
                                       ResourcePathServiceOperation("getRelatedFields", [], self.resource_path))
 
     def delete_object(self):
-        """Deletes the list."""
+        """Deletes the list.
+
+        :rtype: List
+        """
         qry = DeleteEntityQuery(self)
         self.context.add_query(qry)
         self.remove_from_parent_collection()
         return self
 
+    @staticmethod
+    def get_list_data_as_stream(context, listFullUrl, parameters):
+        """
+
+        :type context: ClientContext
+        :type listFullUrl: str
+        :type parameters: RenderListDataParameters
+        :return:
+        """
+        pass
+
     @property
     def enable_folder_creation(self):
         """
@@ -181,7 +234,7 @@ class List(SecurableObject):
             return ListItemCollection(self.context, ResourcePath("items", self.resource_path))
 
     @property
-    def rootFolder(self):
+    def root_folder(self):
         """Get a root folder"""
         if self.is_property_available('RootFolder'):
             return self.properties["RootFolder"]
@@ -194,7 +247,14 @@ class List(SecurableObject):
         if self.is_property_available('Fields'):
             return self.properties['Fields']
         else:
-            return FieldCollection(self.context, ResourcePath("Fields", self.resource_path))
+            return FieldCollection(self.context, ResourcePath("Fields", self.resource_path), self)
+
+    @property
+    def subscriptions(self):
+        """Gets one or more webhook subscriptions on a SharePoint list."""
+        return self.properties.get('Subscriptions',
+                                   SubscriptionCollection(self.context,
+                                                          ResourcePath("Subscriptions", self.resource_path)))
 
     @property
     def views(self):
@@ -206,21 +266,24 @@ class List(SecurableObject):
             return ViewCollection(self.context, ResourcePath("views", self.resource_path), self)
 
     @property
-    def defaultView(self):
+    def default_view(self):
         """Gets or sets a value that specifies whether the list view is the default list view."""
-        if self.is_property_available('DefaultView'):
-            return self.properties['DefaultView']
-        else:
-            return View(self.context, ResourcePath("DefaultView", self.resource_path), self)
+        return self.properties.get('DefaultView',
+                                   View(self.context, ResourcePath("DefaultView", self.resource_path), self))
 
     @property
-    def contentTypes(self):
+    def content_types(self):
         """Gets the content types that are associated with the list."""
-        if self.is_property_available('ContentTypes'):
-            return self.properties['ContentTypes']
-        else:
-            return ContentTypeCollection(self.context,
-                                         ResourcePath("contenttypes", self.resource_path))
+        return self.properties.get('ContentTypes',
+                                   ContentTypeCollection(self.context,
+                                                         ResourcePath("ContentTypes", self.resource_path)))
+
+    @property
+    def user_custom_actions(self):
+        """Gets the User Custom Actions that are associated with the list."""
+        return self.properties.get('UserCustomActions',
+                                   UserCustomActionCollection(self.context,
+                                                              ResourcePath("UserCustomActions", self.resource_path)))
 
     @property
     def forms(self):
@@ -228,6 +291,13 @@ class List(SecurableObject):
         return self.properties.get('Forms',
                                    FormCollection(self.context, ResourcePath("forms", self.resource_path)))
 
+    @property
+    def parent_web(self):
+        """Gets a value that specifies the web where list resides."""
+        from office365.sharepoint.webs.web import Web
+        return self.properties.get('ParentWeb',
+                                   Web(self.context, ResourcePath("parentWeb", self.resource_path)))
+
     @property
     def item_count(self):
         """Gets a value that specifies the number of list items in the list.
@@ -259,6 +329,24 @@ class List(SecurableObject):
         """Sets the description for the list."""
         self.set_property('Description', val)
 
+    @property
+    def parent_web_path(self):
+        return self.properties.get('ParentWebPath', None)
+
+    def get_property(self, name):
+        if name == "UserCustomActions":
+            return self.user_custom_actions
+        elif name == "ParentWeb":
+            return self.parent_web
+        elif name == "RootFolder":
+            return self.root_folder
+        elif name == "ContentTypes":
+            return self.content_types
+        elif name == "DefaultView":
+            return self.default_view
+        else:
+            return super(List, self).get_property(name)
+
     def set_property(self, name, value, persist_changes=True):
         super(List, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
