@@ -1,5 +1,6 @@
 from unittest import TestCase
 
+from office365.runtime.auth.authentication_context import AuthenticationContext
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.sharepoint.tenant.administration.secondary_administrators_fields_data import \
     SecondaryAdministratorsFieldsData
@@ -9,7 +10,6 @@ from tests import random_seed
 from office365.runtime.auth.client_credential import ClientCredential
 from office365.runtime.auth.providers.acs_token_provider import ACSTokenProvider
 from office365.runtime.auth.providers.saml_token_provider import SamlTokenProvider
-from office365.runtime.auth.token_response import TokenResponse
 from office365.runtime.auth.user_credential import UserCredential
 from office365.runtime.http.request_options import RequestOptions
 from office365.sharepoint.client_context import ClientContext
@@ -25,28 +25,34 @@ class TestSharePointClient(TestCase):
                                        settings.get('client_credentials').get('client_secret'))
         ctx = ClientContext(settings['url']).with_credentials(credentials)
         self.assertIsInstance(ctx.authentication_context._provider, ACSTokenProvider)
-        # self.assertIsInstance(ctx.authentication_context.provider.token, TokenResponse)
 
-    def test2_connect_with_user_credentials(self):
+    def test2_connect_with_app_principal_alt(self):
+        context_auth = AuthenticationContext(url=settings.get('url'))
+        context_auth.acquire_token_for_app(client_id=settings.get('client_credentials').get('client_id'),
+                                           client_secret=settings.get('client_credentials').get('client_secret'))
+        ctx = ClientContext(settings.get('url'), context_auth)
+        self.assertIsInstance(ctx.authentication_context._provider, ACSTokenProvider)
+
+    def test4_connect_with_user_credentials(self):
         ctx = ClientContext(settings['url']).with_credentials(user_credentials)
         self.assertIsInstance(ctx.authentication_context._provider, SamlTokenProvider)
 
-    def test3_init_from_url(self):
+    def test5_init_from_url(self):
         ctx = ClientContext.from_url(settings['url']).with_credentials(user_credentials)
         web = ctx.web.get().execute_query()
         self.assertIsNotNone(web.url)
 
-    def test4_connect_with_client_cert(self):
+    def test6_connect_with_client_cert(self):
         pass
 
-    def test5_construct_get_request(self):
+    def test7_construct_get_request(self):
         client = ClientContext(settings['url']).with_credentials(user_credentials)
-        request = client.web.currentUser.get().build_request()
+        request = client.web.current_user.get().build_request()
         self.assertIsInstance(request, RequestOptions)
 
-    def test7_execute_get_batch_request(self):
+    def test8_execute_get_batch_request(self):
         client = ClientContext(settings['url']).with_credentials(user_credentials)
-        current_user = client.web.currentUser
+        current_user = client.web.current_user
         client.load(current_user)
         current_web = client.web
         client.load(current_web)
@@ -54,7 +60,7 @@ class TestSharePointClient(TestCase):
         self.assertIsNotNone(current_web.url)
         self.assertIsNotNone(current_user.user_id)
 
-    def test8_execute_update_batch_request(self):
+    def test9_execute_update_batch_request(self):
         client = ClientContext(settings['url']).with_credentials(user_credentials)
         web = client.web
         new_web_title = "Site %s" % random_seed
@@ -67,7 +73,7 @@ class TestSharePointClient(TestCase):
         client.execute_query()
         self.assertEqual(updated_web.properties['Title'], new_web_title)
 
-    def test9_execute_get_and_update_batch_request(self):
+    def test_10_execute_get_and_update_batch_request(self):
         client = ClientContext(settings['url']).with_credentials(user_credentials)
         list_item = client.web.get_file_by_server_relative_url("/SitePages/Home.aspx").listItemAllFields
         new_title = "Page %s" % random_seed
@@ -80,28 +86,28 @@ class TestSharePointClient(TestCase):
         client.execute_query()
         self.assertEqual(updated_list_item.properties['Title'], new_title)
 
-    def test_10_create_and_delete_batch_request(self):
+    def test_11_create_and_delete_batch_request(self):
         pass
 
-    def test_11_get_and_delete_batch_request(self):
+    def test_12_get_and_delete_batch_request(self):
         file_name = "TestFile{0}.txt".format(random_seed)
         client = ClientContext(settings['url']).with_credentials(user_credentials)
         list_pages = client.web.lists.get_by_title("Documents")
-        files = list_pages.rootFolder.files
+        files = list_pages.root_folder.files
         client.load(files)
         client.execute_query()
         files_count_before = len(files)
-        new_file = list_pages.rootFolder.upload_file(file_name, "-some content goes here-")
+        new_file = list_pages.root_folder.upload_file(file_name, "-some content goes here-")
         client.execute_query()
         self.assertTrue(new_file.name, file_name)
 
         new_file.delete_object()
-        files_after = list_pages.rootFolder.files
+        files_after = list_pages.root_folder.files
         client.load(files_after)
         client.execute_batch()
         self.assertTrue(len(files_after), files_count_before)
 
-    def test_12_get_entity_type_name(self):
+    def test_13_get_entity_type_name(self):
         str_col = ClientValueCollection(str, [])
         self.assertEqual(str_col.entity_type_name, "Collection(Edm.String)")
 
@@ -113,4 +119,5 @@ class TestSharePointClient(TestCase):
                          "Microsoft.Online.SharePoint.TenantAdministration.SecondaryAdministratorsFieldsData")
 
         type_col = ClientValueCollection(SecondaryAdministratorsFieldsData)
-        self.assertEqual(type_col.entity_type_name, "Collection(Microsoft.Online.SharePoint.TenantAdministration.SecondaryAdministratorsFieldsData)")
+        expected_type = "Collection(Microsoft.Online.SharePoint.TenantAdministration.SecondaryAdministratorsFieldsData)"
+        self.assertEqual(type_col.entity_type_name, expected_type)
